import Element from './Element';
import IDOMTokenList from './IDOMTokenList';
/**
 * DOM Token List.
 */
export default class DOMTokenList implements IDOMTokenList<string> {
    private _ownerElement;
    private _list;
    /**
     * Adds class names.
     *
     * @param ownerElement Owner element.
     */
    constructor(ownerElement: Element);
    /**
     * Get ClassName.
     *
     * @param index Index.
     * */
    item(index: number): string;
    /**
     * Replace Token.
     *
     * @param token Token.
     * @param newToken NewToken.
     */
    replace(token: string, newToken: string): boolean;
    /**
     * Supports.
     *
     * @param token Token.
     */
    supports(token: string): boolean;
    /**
     * Returns an iterator, allowing you to go through all values of the key/value pairs contained in this object.
     *
     *
     */
    values(): IterableIterator<string>;
    /**
     * Returns an iterator, allowing you to go through all key/value pairs contained in this object.
     *
     *
     */
    entries(): IterableIterator<[number, string]>;
    /**
     * Executes a provided callback function once for each DOMTokenList element.
     *
     * @param callback
     * @param thisArg
     */
    forEach(callback: (currentValue: any, currentIndex: any, listObj: any) => void, thisArg?: this): void;
    /**
     * Returns an iterator, allowing you to go through all keys of the key/value pairs contained in this object.
     *
     */
    keys(): IterableIterator<number>;
    /**
     * Adds class names.
     *
     * @param classNames Class names.
     */
    add(...classNames: string[]): void;
    /**
     * Removes class names.
     *
     * @param classNames Class names.
     */
    remove(...classNames: string[]): void;
    /**
     * Check if the list contains a class.
     *
     * @param className Class name.
     * @returns TRUE if it contains.
     */
    contains(className: string): boolean;
    /**
     * Toggle a class name.
     *
     * @param className A string representing the class name you want to toggle.
     * @param force If included, turns the toggle into a one way-only operation. If set to `false`, then class name will only be removed, but not added. If set to `true`, then class name will only be added, but not removed.
     * @returns A boolean value, `true` or `false`, indicating whether class name is in the list after the call or not.
     */
    toggle(className: string, force?: boolean): boolean;
    /**
     * Refresh list from class.
     */
    private _refreshListFromClass;
    /**
     * Set Value.
     */
    set value(value: string);
    /**
     * Get Value.
     */
    get value(): string;
    /**
     * Get Length.
     */
    get length(): number;
}
